#!/usr/bin/env python

import argparse
import socket
import sys
import time
import struct
import json


verbose = False
server_ip = "127.0.0.1"
server_port = 10051

def send(server_address, data):
    if verbose:
        print("Connecting " + str(server_address))
    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    sock.connect(server_address)
    if verbose:
        print("Connected")

    try:
        if verbose:
            print("Sending...")
        sock.sendall(data)

        received = 1
        data = ""
        while received > 0:
            chunk = sock.recv(100)
            received = len(chunk)
            data += chunk
        if verbose:
            print("Received: " + data[13:])
        else:
            r = json.loads(data[13:])
            print("Result: " + r["response"])

    finally:
        if verbose:
            print("Closing connection")
        sock.close()

def send_item_data(host, key, value, time):
    global server_ip
    global server_port
    print("TIME: "+str(time))
    request = {
        "request": "sender data",
        "data": [
            {
                "host": host,
                "key": key,
                "value": value
            }
        ]
    }
    if time:
        request["data"][0]["clock"] = time
    data = json.dumps(request, separators=(',', ':'))
    if verbose:
        print("Sending data: " + data)
    packet = "ZBXD\1" + struct.pack('<Q', len(data)) + data
    server_address = (server_ip, server_port)
    send(server_address, packet)

def main():
    global verbose
    global server_ip
    global server_port
    parser = argparse.ArgumentParser()
    parser.add_argument("-v", "--verbose", help="Verbose", action="store_true")
    parser.add_argument("-z", "--zabbix_server", help="Server IP", type=str)
    parser.add_argument("-p", "--port", help="Server port", type=int)
    parser.add_argument("-t", "--time", help="Metric sample time", type=int)
    parser.add_argument("-s", "--host", help="Host name", type=str, required=True)
    parser.add_argument("-k", "--key", help="Item key", type=str, required=True)
    parser.add_argument("-o", "--value", help="Item value", type=str, required=True)
    options = parser.parse_args()
    if options.verbose:
        verbose = True;
    if options.zabbix_server:
        server_ip = options.zabbix_server
    if options.port:
        server_port = options.port
    send_item_data(options.host, options.key, options.value, options.time)
    exit(0)

if __name__ == "__main__":
    main()
